combine_mles_with_aggregate

Function combine_mles_with_aggregate 

pub fn combine_mles_with_aggregate<F: Field>(
    mles: &[DenseMle<F>],
    chal_point: &[F],
) -> Result<F>
This function takes in a list of mles, a challenge point we want to combine them under, and returns the final value in the bookkeeping table of the combined mle. This is equivalent to combining all of these mles according to their prefix bits, and then fixing variable on this combined mle (which is the layerwise bookkeeping table). Instead, we fix variable as we combine as this keeps the bookkeeping table sizes at one.