pub fn get_indexed_layer_mles_to_combine<F: Field>(
mles: Vec<DenseMle<F>>,
) -> Vec<DenseMle<F>>Expand description
Function that prepares all the mles to be combined. We simply index all the MLEs that are to be fixed and combined, and ensure that all fixed bits are always contiguous.