fn get_lsb_fixed_var<F: Field>(mles: &[(F, Vec<bool>)]) -> &(F, Vec<bool>)Expand description
Gets the index of the least significant bit (lsb) of the fixed bits out of a vector of MLEs.
In other words, this is the MLE evaluation pertaining to the MLE with the most fixed bits.