fn split_mle<F: Field>(mle: &DenseMle<F>) -> Vec<DenseMle<F>>Expand description
This function takes an MLE that has a free variable in between fixed
variables, and it splits it into two MLEs, one where the free variable is
replaced with Fixed(false), and the other where it is replaced with
Fixed(true). This ensures that all the fixed bits are contiguous. NOTE we
assume that this function is called on an mle that has a free variable
within a bunch of fixed variables (note how it is used in the
collapse_mles_with_free_in_prefix function)